# ModelArtifact


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **int** |  | [readonly] 
**created_dt** | **datetime** |  | [readonly] 
**version** | **str** |  | [readonly] 
**labels** | **str** |  | [readonly] 
**artifacts** | **str** |  | [readonly] 
**artifact_types** | [**list[ArtifactTypesEnum]**](ArtifactTypesEnum.md) |  | [readonly] 
**metadata** | **dict(str, object)** |  | [readonly] 
**url** | **str** |  | [readonly] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


